#region Copyright Syncfusion Inc. 2001 - 2015
// Copyright Syncfusion Inc. 2001 - 2015. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Grid;
using System.IO;

namespace DataTable_Transpose
{
    public partial class Form1 : Form
    {
        DataSet dataSet;
        public Form1()
        {
            InitializeComponent();
            dataSet = new DataSet();

            #region GDBG LookAndFeel
            this.gridDataBoundGrid1.DefaultRowHeight = 18;
            this.gridDataBoundGrid1.DefaultColWidth = 70;
            #endregion

            #region Initial Data
            this.CreateTable();
            this.gridDataBoundGrid1.DataSource = this.GDBC1Table;            
            #endregion
        }

        #region Properties
        //These properties are used to maintain the DataSource
        private DataTable _GDBC1Table;
        public DataTable GDBC1Table
        {
            get { return _GDBC1Table; }
            set { _GDBC1Table = value; }
        }

        private DataTable _GDBC2Table;
        public DataTable GDCB2Table
        {
            get { return _GDBC2Table; }
            set { _GDBC2Table = value; }
        }
        #endregion

        #region Initial DataSource
        /// <summary>
        /// Default datasource
        /// </summary>
        void CreateTable()
        {            
            ReadXml(dataSet, @"GDBDdata.XML");           
            this.gridDataBoundGrid1.DataSource = dataSet.Tables["Products"];            
            this.GDBC1Table = dataSet.Tables["Products"]; ;
        }
        #endregion

        void ReadXml(DataSet ds, string xmlFileName)
        {
            for (int n = 0; n < 10; n++)
            {
                if (System.IO.File.Exists(xmlFileName))
                {
                    ds.ReadXml(xmlFileName);
                    break;
                }
                xmlFileName = @"..\" + xmlFileName;
            }
        }       

        #region Transpose DataSource
        /// <summary>
        /// Used to tranpose the grid datasource
        /// </summary>
        void CreateTable2()
        {
            //Creating the Temporary DataTable
            DataTable _GdcTable = new DataTable();

            //Creating the columns 
            for (int i = 0; i < this.GDBC1Table.Rows.Count; i++)
            {
                _GdcTable.Columns.Add("Sample" + i);
            }           
           
            int colCount = this.gridDataBoundGrid1.Model.ColCount;

            //Generating the data for transposed grid.
            for (int c = 1; c <= colCount; c++)
            {
                DataRow dr = _GdcTable.NewRow();
                for (int rowIndex = 1; rowIndex < this.GDBC1Table.Rows.Count; rowIndex++)
                {                    
                    dr[rowIndex - 1] = this.gridDataBoundGrid1.Model[rowIndex, c].CellValue;
                }

                _GdcTable.Rows.Add(dr);              
            }

            //Assigning the datasource
            this._GDBC2Table = _GdcTable;
        }
        #endregion

        #region Events

        void Model_QueryRowCount(object sender, GridRowColCountEventArgs e)
        {
            e.Count = this.GDBC1Table.Columns.Count;
            e.Handled = true;
        }

        void Model_QueryCellInfo(object sender, GridQueryCellInfoEventArgs e)
        {
            //Used to set the row header names
            if (e.ColIndex == 0 && e.RowIndex > 0)
            {
                e.Style.CellType = "Header";
                e.Style.CellValue = this.GDBC1Table.Columns[e.RowIndex - 1].ColumnName;       
            }

            //Used to hide the column header text when grid is tranposed
            if (e.RowIndex == 0 && e.ColIndex > 0)
            {
                e.Style.CellValue = string .Empty;
            }
        }
        
        private void transposeBtn_Click(object sender, EventArgs e)
        {     
            
            //To hide the column headers for look and feel
            this.gridDataBoundGrid1.ShowColumnHeaders = false;


            //To set the RowHeader cellvalues as column names
            this.gridDataBoundGrid1.Model.QueryCellInfo += new GridQueryCellInfoEventHandler(Model_QueryCellInfo);

            //Maintaining the RowCount
            this.gridDataBoundGrid1.Model.QueryRowCount += new GridRowColCountEventHandler(Model_QueryRowCount);

            //Generating the DataSource (Transposing the DataSource)
            this.CreateTable2();

            //Assigning the Transposed datasource
            this.gridDataBoundGrid1.DataSource = this._GDBC2Table;

            //To set RowHeader width
            this.gridDataBoundGrid1.Model.ColWidths.ResizeToFit(GridRangeInfo.Table());
        }
        #endregion       

    }
}